ROC_curve: ROC curve

View source: R/ROC_curve.R

ROC_curveR Documentation

ROC curve

Description

Plot ROC curve together with recall / 1-precision curve.

Usage

ROC_curve(actual, predicted, d = c(0.01, 0.05, 0.1, 0.5))

Arguments

actual

A vector of actual values (1/0 or TRUE/FALSE)

predicted

A vector of predicted probabilities (numeric values in [0,1])

d

A nonnegative numeric vector of length 4 with robust-MCC parameters

Details

Instead of a precision-recall curve, a recall / 1-precision curve is plotted in the same coordinate system as the ROC curve.

Grey circles show the corresponding MCC optimal points; black symbols show points optimal with respect to the robust MCC for different values of d.

Value

ROC curve.

References

Holzmann, H., Klar, B. (2026). Robust performance metrics for imbalanced classification problems. arXiv:2404.07661. LINK

Examples

actual <- rf.data[, 1]
predicted <- rf.data[, 2]
ROC_curve(actual, predicted, d=c(0.01,0.02,0.1,0.5))


RobustMetrics documentation built on Aug. 21, 2026, 5:17 p.m.