| rf.data | R Documentation |
This dataset contains example data from a Random Forest model.
rf.data
A data frame with 2 columns:
Actual values
Predicted probabilities
Full test data set using random forest classifier, see Section 6 in Reference.
Holzmann, H., Klar, B. (2026). Robust performance metrics for imbalanced classification problems. arXiv:2404.07661. LINK
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.