| ROC_curve | R Documentation |
Plot ROC curve together with recall / 1-precision curve.
ROC_curve(actual, predicted, d = c(0.01, 0.05, 0.1, 0.5))
actual |
A vector of actual values (1/0 or TRUE/FALSE) |
predicted |
A vector of predicted probabilities (numeric values in |
d |
A nonnegative numeric vector of length 4 with robust-MCC parameters |
Instead of a precision-recall curve, a recall / 1-precision curve is plotted in the same coordinate system as the ROC curve.
Grey circles show the corresponding MCC optimal points; black symbols show points optimal with respect to the robust MCC for different values of d.
ROC curve.
Holzmann, H., Klar, B. (2026). Robust performance metrics for imbalanced classification problems. arXiv:2404.07661. LINK
actual <- rf.data[, 1]
predicted <- rf.data[, 2]
ROC_curve(actual, predicted, d=c(0.01,0.02,0.1,0.5))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.